TransferFunctions
=================

.. toctree::
   :maxdepth: 3

.. automodule:: psyneulink.core.components.functions.transferfunctions
   :members: TransferFunction, Identity, Linear, Exponential, Logistic, Tanh, ReLU, Gaussian, GaussianDistort, SoftMax, LinearMatrix, TransferWithCosts, CostFunctions
   :private-members:
   :exclude-members: Parameters
